// Generated by dts-bundle-generator v8.1.2

declare enum ProcessState {
	Pending = "Pending",
	Processed = "Processed",
	Sent = "Sent",
	Delivered = "Delivered",
	Failed = "Failed"
}
/**
 * Represents the state of a recipient of an SMS message.
 */
export interface RecipientState {
	/**
	 * The phone number of the recipient.
	 */
	phoneNumber: string;
	/**
	 * The state of the recipient.
	 */
	state: ProcessState;
	/**
	 * An optional error message, if the recipient failed to receive the message.
	 */
	error?: string | null;
}
/**
 * Represents the state of an SMS message.
 */
export interface MessageState {
	/**
	 * The ID of the message.
	 */
	id: string;
	/**
	 * The state of the message.
	 */
	state: ProcessState;
	/**
	 * The list of recipients' states for the message.
	 */
	recipients: RecipientState[];
}
/**
 * Represents an SMS message.
 */
export interface Message {
	/**
	 * The ID of the message, will be generated if not provided.
	 * @default null
	 */
	id?: string | null;
	/**
	 * The message content.
	 */
	message: string;
	/**
	 * The time-to-live (TTL) of the message in seconds.
	 * If set to null, the message will not expire.
	 * @default null
	 */
	ttl?: number | null;
	/**
	 * The phone numbers to send the message to.
	 */
	phoneNumbers: string[];
	/**
	 * The SIM number to send the message from.
	 * If not specified, the message will be sent from the default SIM.
	 * @default null
	 */
	simNumber?: number | null;
	/**
	 * Whether to include a delivery report for the message.
	 * @default true
	 */
	withDeliveryReport?: boolean | null;
}
declare enum WebHookEventType {
	/**
	 * Indicates that a new SMS message has been received.
	 */
	SmsReceived = "sms:received",
	/**
	 * Indicates that a ping request has been sent.
	 */
	SystemPing = "system:ping"
}
/**
 * Represents a request to create or update a webhook.
 */
export interface RegisterWebHookRequest {
	/**
	 * The ID of the webhook.
	 * If not specified, a new ID will be generated.
	 * @default null
	 */
	id?: string | null;
	/**
	 * The event type that triggers the webhook.
	 */
	event: WebHookEventType;
	/**
	 * The URL to send the webhook request to.
	 */
	url: string;
}
/**
 * Represents a webhook configuration.
 * @see RegisterWebHookRequest
 */
export type WebHook = Required<RegisterWebHookRequest>;
export interface HttpClient {
	get<T>(url: string, headers?: Record<string, string>): Promise<T>;
	post<T>(url: string, body: any, headers?: Record<string, string>): Promise<T>;
	delete<T>(url: string, headers?: Record<string, string>): Promise<T>;
}
declare class Client {
	private baseUrl;
	private httpClient;
	private defaultHeaders;
	constructor(login: string, password: string, httpClient: HttpClient, baseUrl?: string);
	send(request: Message): Promise<MessageState>;
	getState(messageId: string): Promise<MessageState>;
	getWebhooks(): Promise<WebHook[]>;
	registerWebhook(request: RegisterWebHookRequest): Promise<WebHook>;
	deleteWebhook(webhookId: string): Promise<void>;
}

export {
	Client as default,
};

export {};
